<?php

namespace Drupal\string_plural_form\Plugin\StringPluralForm;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\string_plural_form\Attribute\StringPluralForm;
use Drupal\string_plural_form\StringPluralFormBase;

/**
 * Provides a Plural Form for "Breton" language.
 */
#[StringPluralForm(
  id: "five_forms_breton",
  admin_label: new TranslatableMarkup("Five Forms Breton"),
  description: new TranslatableMarkup("Case in the Breton language."),
)]
class FiveFormsBreton extends StringPluralFormBase {

  /**
   * {@inheritdoc}
   */
  public function getGettextNplurals(): int {
    return 5;
  }

  /**
   * {@inheritdoc}
   */
  public function getGettextPlural(): string {
    return "(n % 10 == 1 && n % 100 != 11 && n % 100 != 71 && n % 100 != 91) ? 0 : ((n % 10 == 2 && n % 100 != 12 && n % 100 != 72 && n % 100 != 92) ? 1 : ((((n % 10 == 3 || n % 10 == 4) || n % 10 == 9) && (n % 100 < 10 || n % 100 > 19) && (n % 100 < 70 || n % 100 > 79) && (n % 100 < 90 || n % 100 > 99)) ? 2 : ((n != 0 && n % 1000000 == 0) ? 3 : 4)))";
  }

  /**
   * {@inheritdoc}
   */
  public function getAssociatedLanguageCodes(): array {
    return [
      "br",
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIndex(int $n): int {
    return ($n % 10 == 1 && $n % 100 != 11 && $n % 100 != 71 && $n % 100 != 91) ? 0 : (($n % 10 == 2 && $n % 100 != 12 && $n % 100 != 72 && $n % 100 != 92) ? 1 : (((($n % 10 == 3 || $n % 10 == 4) || $n % 10 == 9) && ($n % 100 < 10 || $n % 100 > 19) && ($n % 100 < 70 || $n % 100 > 79) && ($n % 100 < 90 || $n % 100 > 99)) ? 2 : (($n != 0 && $n % 1000000 == 0) ? 3 : 4)));
  }

  /**
   * {@inheritdoc}
   */
  public function getIndexLabel(int $index): TranslatableMarkup {
    return match($index) {
      0 => new TranslatableMarkup("1, 21, 31, 41..."),
      1 => new TranslatableMarkup("2, 22, 32, 42, ..."),
      2 => new TranslatableMarkup("3, 4, 9, 23, 24, 29, ..."),
      3 => new TranslatableMarkup("1000000, 2000000, ..."),
      4 => new TranslatableMarkup("0, 5~8, 10~20, 100, 1000, 10000, ..."),
    };
  }

}
