<?php

namespace Drupal\string_plural_form\Plugin\StringPluralForm;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\string_plural_form\Attribute\StringPluralForm;
use Drupal\string_plural_form\StringPluralFormBase;

/**
 * Provides a custom block plugin.
 */
#[StringPluralForm(
  id: "five_forms_irish",
  admin_label: new TranslatableMarkup("Five Forms, special case for one, two, 3..6, 7..10, [0, 11, 12, ...]"),
  description: new TranslatableMarkup("Case in the language like Gaeilge (Irish)."),
)]
class FiveFormsIrish extends StringPluralFormBase {

  /**
   * {@inheritdoc}
   */
  public function getGettextNplurals(): int {
    return 5;
  }

  /**
   * {@inheritdoc}
   */
  public function getGettextPlural(): string {
    return "n==1 ? 0 : n==2 ? 1 : n>=3 && n<=6 ? 2 : n>=7 && n<=10 ? 3 : 4";
  }

  /**
   * {@inheritdoc}
   */
  public function getAssociatedLanguageCodes(): array {
    return [
      "ga",
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIndex(int $n): int {
    return ($n == 1 ? 0 : ($n == 2 ? 1 : ($n >= 3 && $n <= 6 ? 2 : ($n >= 7 && $n <= 10 ? 3 : 4))));
  }

  /**
   * {@inheritdoc}
   */
  public function getIndexLabel(int $index): TranslatableMarkup {
    return match($index) {
      0 => new TranslatableMarkup("one"),
      1 => new TranslatableMarkup("two"),
      2 => new TranslatableMarkup("3, 4, 5, 6"),
      3 => new TranslatableMarkup("7, 8, 9, 10"),
      4 => new TranslatableMarkup("0, 11, 12, 13..."),
    };
  }

}
