<?php

namespace Drupal\string_plural_form\Plugin\StringPluralForm;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\string_plural_form\Attribute\StringPluralForm;
use Drupal\string_plural_form\StringPluralFormBase;

/**
 * Provides a Plural Form for "Gaelic" language.
 */
#[StringPluralForm(
  id: "four_forms_gaelic",
  admin_label: new TranslatableMarkup("Four Forms Gaelic"),
  description: new TranslatableMarkup("Case in the Gaelic language."),
)]
class FourFormsGaelic extends StringPluralFormBase {

  /**
   * {@inheritdoc}
   */
  public function getGettextNplurals(): int {
    return 4;
  }

  /**
   * {@inheritdoc}
   */
  public function getGettextPlural(): string {
    return "(n == 1 || n == 11) ? 0 : ((n == 2 || n == 12) ? 1 : ((n >= 3 && n <= 10 || n >= 13 && n <= 19) ? 2 : 3))";
  }

  /**
   * {@inheritdoc}
   */
  public function getAssociatedLanguageCodes(): array {
    return [
      "gd",
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIndex(int $n): int {
    return ($n == 1 || $n == 11) ? 0 : (($n == 2 || $n == 12) ? 1 : (($n >= 3 && $n <= 10 || $n >= 13 && $n <= 19) ? 2 : 3));
  }

  /**
   * {@inheritdoc}
   */
  public function getIndexLabel(int $index): TranslatableMarkup {
    return match($index) {
      0 => new TranslatableMarkup("1, 11"),
      1 => new TranslatableMarkup("2, 12"),
      2 => new TranslatableMarkup("3, 4, 5, 6, ..."),
      3 => new TranslatableMarkup("0, 20, 21, 22, ..."),
    };
  }

}
