<?php

namespace Drupal\string_plural_form\Plugin\StringPluralForm;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\string_plural_form\Attribute\StringPluralForm;
use Drupal\string_plural_form\StringPluralFormBase;

/**
 * Provides a custom block plugin.
 */
#[StringPluralForm(
  id: "four_forms_slavic_type_4",
  admin_label: new TranslatableMarkup("Four forms, special case for one and all numbers ending in 02, 03, or 04"),
  description: new TranslatableMarkup("Case in some Slavic family language like Slovenian."),
)]
class FourFormsSlavicType4 extends StringPluralFormBase {

  /**
   * {@inheritdoc}
   */
  public function getGettextNplurals(): int {
    return 4;
  }

  /**
   * {@inheritdoc}
   */
  public function getGettextPlural(): string {
    return "n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3";
  }

  /**
   * {@inheritdoc}
   */
  public function getAssociatedLanguageCodes(): array {
    return [
      "sl",
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIndex(int $n): int {
    return $n % 100 == 1 ? 0 : ($n % 100 == 2 ? 1 : ($n % 100 == 3 || $n % 100 == 4 ? 2 : 3));
  }

  /**
   * {@inheritdoc}
   */
  public function getIndexLabel(int $index): TranslatableMarkup {
    return match($index) {
      0 => new TranslatableMarkup("1, 101, 201, 301..."),
      1 => new TranslatableMarkup("2, 102, 202, 302..."),
      2 => new TranslatableMarkup("3, 4, 103, 104..."),
      3 => new TranslatableMarkup("0, 5, 6, 7..."),
    };
  }

}
