<?php

namespace Drupal\string_plural_form\Plugin\StringPluralForm;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\string_plural_form\Attribute\StringPluralForm;
use Drupal\string_plural_form\StringPluralFormBase;

/**
 * Provides a Plural Form for "Welsh" language.
 */
#[StringPluralForm(
  id: "six_forms_welsh",
  admin_label: new TranslatableMarkup("Six Forms Welsh"),
  description: new TranslatableMarkup("Case in the Welsh language."),
)]
class SixFormsWelsh extends StringPluralFormBase {

  /**
   * {@inheritdoc}
   */
  public function getGettextNplurals(): int {
    return 6;
  }

  /**
   * {@inheritdoc}
   */
  public function getGettextPlural(): string {
    return "(n == 0) ? 0 : ((n == 1) ? 1 : ((n == 2) ? 2 : ((n == 3) ? 3 : ((n == 6) ? 4 : 5))))";
  }

  /**
   * {@inheritdoc}
   */
  public function getAssociatedLanguageCodes(): array {
    return [
      "cy",
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIndex(int $n): int {
    return ($n == 0) ? 0 : (($n == 1) ? 1 : (($n == 2) ? 2 : (($n == 3) ? 3 : (($n == 6) ? 4 : 5))));
  }

  /**
   * {@inheritdoc}
   */
  public function getIndexLabel(int $index): TranslatableMarkup {
    return match($index) {
      0 => new TranslatableMarkup("0"),
      1 => new TranslatableMarkup("1"),
      2 => new TranslatableMarkup("2"),
      3 => new TranslatableMarkup("3"),
      4 => new TranslatableMarkup("6"),
      5 => new TranslatableMarkup("4, 5, 7~20, ..."),
    };
  }

}
