<?php

namespace Drupal\string_plural_form\Plugin\StringPluralForm;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\string_plural_form\Attribute\StringPluralForm;
use Drupal\string_plural_form\StringPluralFormBase;

/**
 * Provides a custom block plugin.
 */
#[StringPluralForm(
  id: "three_forms_slavic_type_1",
  admin_label: new TranslatableMarkup("Three forms, special cases for numbers ending in 1 and 2, 3, 4, except those ending in 1[1-4]"),
  description: new TranslatableMarkup("Case in some Slavic family language like Russian, Ukranian, etc."),
)]
class ThreeFormsSlavicType1 extends StringPluralFormBase {

  /**
   * {@inheritdoc}
   */
  public function getGettextNplurals(): int {
    return 3;
  }

  /**
   * {@inheritdoc}
   */
  public function getGettextPlural(): string {
    return "n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2";
  }

  /**
   * {@inheritdoc}
   */
  public function getAssociatedLanguageCodes(): array {
    return [
      "ru",
      "uk",
      "be",
      "sr",
      "hr",
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIndex(int $n): int {
    return $n % 10 == 1 && $n % 100 != 11 ? 0 : ($n % 10 >= 2 && $n % 10 <= 4 && ($n % 100 < 10 || $n % 100 >= 20) ? 1 : 2);
  }

  /**
   * {@inheritdoc}
   */
  public function getIndexLabel(int $index): TranslatableMarkup {
    return match($index) {
      0 => new TranslatableMarkup("1, 21, 31, 41..."),
      1 => new TranslatableMarkup("2, 3, 4, 22..."),
      2 => new TranslatableMarkup("0, 5, 6, 7..."),
    };
  }

}
