<?php

namespace Drupal\string_plural_form\Plugin\StringPluralForm;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\string_plural_form\Attribute\StringPluralForm;
use Drupal\string_plural_form\StringPluralFormBase;

/**
 * Provides a custom block plugin.
 */
#[StringPluralForm(
  id: "three_forms_slavic_type_2",
  admin_label: new TranslatableMarkup("Three forms, special cases for 1 and 2, 3, 4"),
  description: new TranslatableMarkup("Case in some Slavic family language like Czech, Slovak."),
)]
class ThreeFormsSlavicType2 extends StringPluralFormBase {

  /**
   * {@inheritdoc}
   */
  public function getGettextNplurals(): int {
    return 3;
  }

  /**
   * {@inheritdoc}
   */
  public function getGettextPlural(): string {
    return "(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2";
  }

  /**
   * {@inheritdoc}
   */
  public function getAssociatedLanguageCodes(): array {
    return [
      "cs",
      "sk",
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIndex(int $n): int {
    return ($n == 1) ? 0 : (($n >= 2 && $n <= 4) ? 1 : 2);
  }

  /**
   * {@inheritdoc}
   */
  public function getIndexLabel(int $index): TranslatableMarkup {
    return match($index) {
      0 => new TranslatableMarkup("One"),
      1 => new TranslatableMarkup("2, 3, 4"),
      2 => new TranslatableMarkup("0, 5, 6, 7..."),
    };
  }

}
