<?php

namespace Drupal\string_plural_form\Plugin\StringPluralForm;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\string_plural_form\Attribute\StringPluralForm;
use Drupal\string_plural_form\StringPluralFormBase;

/**
 * Provides a custom block plugin.
 */
#[StringPluralForm(
  id: "three_forms_special_case_for_zero",
  admin_label: new TranslatableMarkup("Three forms, special case for zero"),
  description: new TranslatableMarkup("Case in the language like Latvian."),
)]
class ThreeFormsSpecialCaseForZero extends StringPluralFormBase {

  /**
   * {@inheritdoc}
   */
  public function getGettextNplurals(): int {
    return 3;
  }

  /**
   * {@inheritdoc}
   */
  public function getGettextPlural(): string {
    return "n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2";
  }

  /**
   * {@inheritdoc}
   */
  public function getAssociatedLanguageCodes(): array {
    return [
      "lv",
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIndex(int $n): int {
    return $n % 10 == 1 && $n % 100 != 11 ? 0 : ($n != 0 ? 1 : 2);
  }

  /**
   * {@inheritdoc}
   */
  public function getIndexLabel(int $index): TranslatableMarkup {
    return match($index) {
      0 => new TranslatableMarkup("0, 10, 11, 12..."),
      1 => new TranslatableMarkup("1, 21, 31, 41..."),
      2 => new TranslatableMarkup("2, 3, 4, 5..."),
    };
  }

}
