<?php

namespace Drupal\string_plural_form\Plugin\StringPluralForm;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\string_plural_form\Attribute\StringPluralForm;
use Drupal\string_plural_form\StringPluralFormBase;

/**
 * Provides a Plural Form for "Colognian, Langi" languages.
 */
#[StringPluralForm(
  id: "three_forms_special_case_for_zero_and_one",
  admin_label: new TranslatableMarkup("Three forms, special case for zero and one"),
  description: new TranslatableMarkup("Case in the language Colognian and Langi."),
)]
class ThreeFormsSpecialCaseForZeroAndOne extends StringPluralFormBase {

  /**
   * {@inheritdoc}
   */
  public function getGettextNplurals(): int {
    return 3;
  }

  /**
   * {@inheritdoc}
   */
  public function getGettextPlural(): string {
    return "(n == 0) ? 0 : ((n == 1) ? 1 : 2)";
  }

  /**
   * {@inheritdoc}
   */
  public function getAssociatedLanguageCodes(): array {
    return [
      "ksh",
      "lag",
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIndex(int $n): int {
    return ($n == 0) ? 0 : (($n == 1) ? 1 : 2);
  }

  /**
   * {@inheritdoc}
   */
  public function getIndexLabel(int $index): TranslatableMarkup {
    return match($index) {
      0 => new TranslatableMarkup("0"),
      1 => new TranslatableMarkup("1"),
      2 => new TranslatableMarkup("2, 3, 4, 5, ..."),
    };
  }

}
