<?php

namespace Drupal\string_plural_form\Plugin\StringPluralForm;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\string_plural_form\Attribute\StringPluralForm;
use Drupal\string_plural_form\StringPluralFormBase;

/**
 * Provides a custom block plugin.
 */
#[StringPluralForm(
  id: "three_forms_special_cases_for_one_and_two",
  admin_label: new TranslatableMarkup("Three forms, special cases for one and two"),
  description: new TranslatableMarkup("Case in the language like Gaeilge (Irish)."),
)]
class ThreeFormsSpecialCasesForOneAndTwo extends StringPluralFormBase {

  /**
   * {@inheritdoc}
   */
  public function getGettextNplurals(): int {
    return 3;
  }

  /**
   * {@inheritdoc}
   */
  public function getGettextPlural(): string {
    return "n==1 ? 0 : n==2 ? 1 : 2";
  }

  /**
   * {@inheritdoc}
   */
  public function getAssociatedLanguageCodes(): array {
    return [
      "ga",
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIndex(int $n): int {
    return $n == 1 ? 0 : ($n == 2 ? 1 : 2);
  }

  /**
   * {@inheritdoc}
   */
  public function getIndexLabel(int $index): TranslatableMarkup {
    return match($index) {
      0 => new TranslatableMarkup("One"),
      1 => new TranslatableMarkup("Two"),
      2 => new TranslatableMarkup("3, 4, 5..."),
    };
  }

}
