<?php

namespace Drupal\string_plural_form\Plugin\StringPluralForm;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\string_plural_form\Attribute\StringPluralForm;
use Drupal\string_plural_form\StringPluralFormBase;

/**
 * Provides a Plural Form for "Tachelhit" language.
 */
#[StringPluralForm(
  id: "three_forms_tachelhit",
  admin_label: new TranslatableMarkup("Five Forms Tachelhit"),
  description: new TranslatableMarkup("Case in the Tachelhit language."),
)]
class ThreeFormsTachelhit extends StringPluralFormBase {

  /**
   * {@inheritdoc}
   */
  public function getGettextNplurals(): int {
    return 3;
  }

  /**
   * {@inheritdoc}
   */
  public function getGettextPlural(): string {
    return "(n == 0 || n == 1) ? 0 : ((n >= 2 && n <= 10) ? 1 : 2)";
  }

  /**
   * {@inheritdoc}
   */
  public function getAssociatedLanguageCodes(): array {
    return [
      "mt",
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIndex(int $n): int {
    return ($n == 0 || $n == 1) ? 0 : (($n >= 2 && $n <= 10) ? 1 : 2);
  }

  /**
   * {@inheritdoc}
   */
  public function getIndexLabel(int $index): TranslatableMarkup {
    return match($index) {
      0 => new TranslatableMarkup("0, 1"),
      1 => new TranslatableMarkup("2~10"),
      2 => new TranslatableMarkup("others"),
    };
  }

}
