<?php

namespace Drupal\string_plural_form\Plugin\StringPluralForm;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\string_plural_form\Attribute\StringPluralForm;
use Drupal\string_plural_form\StringPluralFormBase;

/**
 * Provides a Plural Form for "Filipino" language.
 */
#[StringPluralForm(
  id: "two_forms_austronesian",
  admin_label: new TranslatableMarkup("Two Forms Austronesian"),
  description: new TranslatableMarkup("Case in the Filipino language."),
)]
class TwoFormsAustronesian extends StringPluralFormBase {

  /**
   * {@inheritdoc}
   */
  public function getGettextNplurals(): int {
    return 2;
  }

  /**
   * {@inheritdoc}
   */
  public function getGettextPlural(): string {
    return "n != 1 && n != 2 && n != 3 && (n % 10 == 4 || n % 10 == 6 || n % 10 == 9)";
  }

  /**
   * {@inheritdoc}
   */
  public function getAssociatedLanguageCodes(): array {
    return [
      "ceb",
      "fil",
      "tl",
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIndex(int $n): int {
    return $n != 1 && $n != 2 && $n != 3 && ($n % 10 == 4 || $n % 10 == 6 || $n % 10 == 9);
  }

  /**
   * {@inheritdoc}
   */
  public function getIndexLabel(int $index): TranslatableMarkup {
    return match($index) {
      0 => new TranslatableMarkup("0~3, 5, 7, 8, 10~13, 15, 17, ..."),
      1 => new TranslatableMarkup("4, 6, 9, 14, 16, 19, 24, ..."),
    };
  }

}
