<?php

namespace Drupal\string_plural_form\Plugin\StringPluralForm;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\string_plural_form\Attribute\StringPluralForm;
use Drupal\string_plural_form\StringPluralFormBase;

/**
 * Provides a Plural Form for "Icelandic and Macedonian" languages.
 */
#[StringPluralForm(
  id: "two_forms_special_case_for_ending_in_1",
  admin_label: new TranslatableMarkup("Two Forms, special case numbers for ending in 1"),
  description: new TranslatableMarkup("Plural form for Icelandic and Macedonian language."),
)]
class TwoFormsSpecialCaseForEndingIn1 extends StringPluralFormBase {

  /**
   * {@inheritdoc}
   */
  public function getGettextNplurals(): int {
    return 2;
  }

  /**
   * {@inheritdoc}
   */
  public function getGettextPlural(): string {
    return "n % 10 != 1 || n % 100 == 11";
  }

  /**
   * {@inheritdoc}
   */
  public function getAssociatedLanguageCodes(): array {
    return [
      "is",
      "mk",
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIndex(int $n): int {
    return $n % 10 != 1 || $n % 100 == 11;
  }

  /**
   * {@inheritdoc}
   */
  public function getIndexLabel(int $index): TranslatableMarkup {
    return match($index) {
      0 => new TranslatableMarkup("0, 2, 3, 4, ..."),
      1 => new TranslatableMarkup("1, 21, 31, 41, ..."),
    };
  }

}
