<?php

namespace Drupal\string_plural_form;

use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * StringPluralFormPlugin Interface definition.
 */
interface StringPluralFormPluginInterface {

  /**
   * For a given count, get the plural Index.
   *
   * @param int $n
   *   The number for which index needs to be found.
   *
   * @return int
   *   The plural message index.
   */
  public function getIndex(int $n): int;

  /**
   * Get Index label that can be shown for assisting translators.
   *
   * @param int $index
   *   The plural index.
   *
   * @return string
   *   A message string assisting translators to associate corresponding index
   *   with plural form to be used.
   */
  public function getIndexLabel(int $index): TranslatableMarkup;

  /**
   * Generate Local Plural Index as expected by Drupal core.
   *
   * @param int|null $max
   *   Optional max number of items to calculate index for.
   *
   * @return array
   *   Map of count versus their index value.
   */
  public function generateLocalePluralIndex(?int $max = 199): array;

  /**
   * Gets associated language code for the rule.
   *
   * @return string[]
   *   List of associated language code in ISO 639 format.
   */
  public function getAssociatedLanguageCodes(): array;

  /**
   * Gets total number of plural forms.
   *
   * @return int
   *   Total number of plural count.
   */
  public function getGettextNplurals(): int;

  /**
   * Gets plural form rule.
   *
   * @return string
   *   The plural rule as defined for a language in Gettext.
   */
  public function getGettextPlural(): string;

}
